@@ -8,6 +8,7 @@ from loguru import logger
 from rich.console import Console
 from rich.table import Table
 from flask_socketio_web.action import get_actions
+from waitress import serve
 
 # log = logging.getLogger('werkzeug')
 # log.setLevel(logging.ERROR)
@@ -76,7 +77,7 @@ class FlaskSocketioWeb(object):
                 table.add_row(event, namespace, "-", "-")
         console.print(table)
 
-    def run(self, host='0.0.0.0', port=8090, debug_server=None, debug=True):
+    def run(self, host='0.0.0.0', port=8090, debug_server=None, debug=True, **kwargs):
         try:
             if len(sys.argv) > 1 and sys.argv[1] == 'debug' or debug_server:
                 import pydevd_pycharm
@@ -89,7 +90,9 @@ class FlaskSocketioWeb(object):
 
             logger.info(f"Running on port http://{host}:{port}")
             self.app.logger = logger
-            self.app.run(host=host, port=port, threaded=True, debug=debug)
-
+            if debug:
+                self.app.run(host=host, port=port, debug=debug, **kwargs)
+            else:
+                serve(self.app, host=host, port=port, **kwargs)
         except Exception as e:
             logger.exception(e)
